require 'fog'
require 'puppet/face'
require 'puppet/cloudpack/vmware'

Puppet::Face.define(:node_vmware, '0.0.1') do
  action :create do
    summary "Create a new VM from a template"
    description <<-'EOT'
      This action creates a new virtual machine by cloning an existing VMware
      VM marked as a template.
    EOT

    returns 'Hash containing attributes about the new virtual machine.'

    examples <<-'EOT'
      $ puppet node_vmware create --vmname jefftest --template /Datacenters/Solutions/vm/el56
    EOT

    Puppet::CloudPack::VMware.add_create_options(self)

    when_invoked do |options|
      options[:wait] = true if options[:wait_for_boot]
      Puppet::CloudPack::VMware.create(options)
    end

    when_rendering :console do |return_value|
      return_value.to_yaml
    end
  end
end
